@@ -1,19 +1,22 @@
 /* -*- mode: c++; c-basic-offset: 4; indent-tabs-mode: nil; -*-
-
     utils/formatting.cpp
 
     This file is part of Kleopatra, the KDE keymanager
     SPDX-FileCopyrightText: 2007 Klarälvdalens Datakonsult AB
+    SPDX-FileCopyrightText: 2021 g10 Code GmbH
+    SPDX-FileContributor: Ingo Klöcker <dev@ingo-kloecker.de>
 
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
+#include <config-libkleo.h>
+
 #include "formatting.h"
 #include "kleo/dn.h"
 #include "kleo/keyfiltermanager.h"
 #include "kleo/keygroup.h"
 
-#include "utils/compat.h"
+#include "utils/cryptoconfig.h"
 
 #include <gpgme++/key.h>
 #include <gpgme++/importresult.h>
@@ -25,7 +28,6 @@
 #include <KEmailAddress>
 
 #include <QString>
-#include <QStringList>
 #include <QDateTime>
 #include <QTextDocument> // for Qt::escape
 #include <QLocale>
@@ -316,14 +318,14 @@ QString Formatting::toolTip(const Key &key, int flags)
 
     QString result;
     if (flags & Validity) {
-        if (key.protocol() == OpenPGP || (key.keyListMode() & Validate))
+        if (key.protocol() == OpenPGP || (key.keyListMode() & Validate)) {
             if (key.isRevoked()) {
                 result = make_red(i18n("Revoked"));
             } else if (key.isExpired()) {
                 result = make_red(i18n("Expired"));
             } else if (key.isDisabled()) {
                 result = i18n("Disabled");
-            } else {
+            } else if (key.keyListMode() & GpgME::Validate) {
                 unsigned int fullyTrusted = 0;
                 for (const auto &uid: key.userIDs()) {
                     if (uid.validity() >= UserID::Validity::Full) {
@@ -339,8 +341,10 @@ QString Formatting::toolTip(const Key &key, int flags)
                 } else {
                     result = i18np("One User-ID is not certified.", "%1 User-IDs are not certified.", key.numUserIDs() - fullyTrusted);
                 }
+            } else {
+                result = i18n("The validity cannot be checked at the moment.");
             }
-        else {
+        } else {
             result = i18n("The validity cannot be checked at the moment.");
         }
     }
@@ -494,12 +498,12 @@ QString Formatting::toolTip(const KeyGroup &group, int flags)
     QStringList result;
     result.reserve(3 + 2 + numKeysForTooltip + 2);
     if (!validity.isEmpty()) {
-        result.push_back("<p>");
+        result.push_back(QStringLiteral("<p>"));
         result.push_back(validity.toHtmlEscaped());
-        result.push_back("</p>");
+        result.push_back(QStringLiteral("</p>"));
     }
 
-    result.push_back("<p>");
+    result.push_back(QStringLiteral("<p>"));
     result.push_back(i18n("Keys:"));
     {
         auto it = keys.cbegin();
@@ -510,7 +514,7 @@ QString Formatting::toolTip(const KeyGroup &group, int flags)
     if (keys.size() > numKeysForTooltip) {
         result.push_back(QLatin1String("<br>") + i18ncp("this follows a list of keys", "and 1 more key", "and %1 more keys", keys.size() - numKeysForTooltip));
     }
-    result.push_back("</p>");
+    result.push_back(QStringLiteral("</p>"));
 
     return result.join(QLatin1Char('\n'));
 }
@@ -1079,15 +1083,8 @@ bool Formatting::uidsHaveFullValidity(const Key &key)
 
 QString Formatting::complianceMode()
 {
-    const QGpgME::CryptoConfig *const config = QGpgME::cryptoConfig();
-    if (!config) {
-        return QString();
-    }
-    const QGpgME::CryptoConfigEntry *const entry = getCryptoConfigEntry(config, "gpg", "compliance");
-    if (!entry || entry->stringValue() == QLatin1String("gnupg")) {
-        return QString();
-    }
-    return entry->stringValue();
+    const auto complianceValue = getCryptoConfigStringValue("gpg", "compliance");
+    return complianceValue == QLatin1String("gnupg") ? QString() : complianceValue;
 }
 
 bool Formatting::isKeyDeVs(const GpgME::Key &key)
@@ -1122,7 +1119,8 @@ QString Formatting::complianceStringForKey(const GpgME::Key &key)
 
 QString Formatting::complianceStringShort(const GpgME::Key &key)
 {
-    if (Formatting::uidsHaveFullValidity(key)) {
+    const bool keyValidityChecked = (key.keyListMode() & GpgME::Validate);
+    if (keyValidityChecked && Formatting::uidsHaveFullValidity(key)) {
         if (complianceMode() == QLatin1String("de-vs")
             && Formatting::isKeyDeVs(key)) {
             return QStringLiteral("★ ") + deVsString(true);
@@ -1141,8 +1139,11 @@ QString Formatting::complianceStringShort(const GpgME::Key &key)
     if (key.isInvalid()) {
         return i18n("invalid");
     }
+    if (keyValidityChecked) {
+        return i18nc("As in not all user IDs are valid.", "not certified");
+    }
 
-    return i18nc("As in not all user IDs are valid.", "not certified");
+    return i18nc("The validity of the user IDs has not been/could not be checked", "not checked");
 }
 
 QString Formatting::complianceStringShort(const KeyGroup &group)
@@ -1204,3 +1205,47 @@ QString Formatting::deVsString(bool compliant)
     }
     return filter->name();
 }
+
+namespace
+{
+QString formatTrustScope(const char *trustScope)
+{
+    static const QRegularExpression escapedNonAlphaNum{QStringLiteral(R"(\\([^0-9A-Za-z]))")};
+
+    const auto scopeRegExp = QString::fromUtf8(trustScope);
+    if (scopeRegExp.startsWith(u"<[^>]+[@.]") && scopeRegExp.endsWith(u">$")) {
+        // looks like a trust scope regular expression created by gpg
+        auto domain = scopeRegExp.mid(10, scopeRegExp.size() - 10 - 2);
+        domain.replace(escapedNonAlphaNum, QStringLiteral(R"(\1)"));
+        return domain;
+    }
+    return scopeRegExp;
+}
+}
+
+QString Formatting::trustSignatureDomain(const GpgME::UserID::Signature &sig)
+{
+#ifdef GPGMEPP_SUPPORTS_TRUST_SIGNATURES
+    return formatTrustScope(sig.trustScope());
+#else
+    return {};
+#endif
+}
+
+QString Formatting::trustSignature(const GpgME::UserID::Signature &sig)
+{
+#ifdef GPGMEPP_SUPPORTS_TRUST_SIGNATURES
+    switch (sig.trustValue()) {
+    case TrustSignatureTrust::Partial:
+        return i18nc("Certifies this key as partially trusted introducer for 'domain name'.",
+                     "Certifies this key as partially trusted introducer for '%1'.", trustSignatureDomain(sig));
+    case TrustSignatureTrust::Complete:
+        return i18nc("Certifies this key as fully trusted introducer for 'domain name'.",
+                     "Certifies this key as fully trusted introducer for '%1'.", trustSignatureDomain(sig));
+    default:
+        return {};
+    }
+#else
+    return {};
+#endif
+}
